
Include anti-caching headers
-------

**Description:**

Anti-caching headers have the ability to tell the browser, 
computer and proxies what information they may or may not store on the intermediate media


**Solution:**

These headers are also known as the: Cache-control: no-store,no-cache and provide 
protection of sensitive information when implemented in the application or webserver.

	